ItsfoundBarcode (itsfound_barcode v0.1.5)
View Sourcethis is the public api for the barcode scanning functions
it should be called like this:
ItsfoundBarcode.scan()
this is the public api for the barcode scanning functions
it should be called like this:
ItsfoundBarcode.scan()